@@ -5,12 +5,12 @@ from loguru import logger
 
 from hdx.utilities.easy_logging import setup_logging
 
+setup_logging(log_file="errors.log")
+
+
 standard_logger = logging.getLogger(__name__)
 
 
-setup_logging(error_file=True)
-
-
 class TestLogging:
     def test_setup_logging(self, caplog):
         with caplog.at_level(logging.ERROR):
